==> Paws-0.35.tar.gz: Paws-0.35/lib/Paws/RDS/DescribeAccountAttributes.pm <==

package Paws::RDS::DescribeAccountAttributes;
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeAccountAttributes');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::RDS::AccountAttributesMessage');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'DescribeAccountAttributesResult');
1;

### main pod documentation begin ###

=head1 NAME

Paws::RDS::DescribeAccountAttributes - Arguments for method DescribeAccountAttributes on Paws::RDS

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeAccountAttributes on the 
Amazon Relational Database Service service. Use the attributes of this class
as arguments to method DescribeAccountAttributes.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeAccountAttributes.

As an example:

  $service_obj->DescribeAccountAttributes(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeAccountAttributes in L<Paws::RDS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.44.tar.gz: Paws-0.44/lib/Paws/RDS/DescribeAccountAttributes.pm <==

package Paws::RDS::DescribeAccountAttributes;
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeAccountAttributes');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::RDS::AccountAttributesMessage');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'DescribeAccountAttributesResult');
1;

### main pod documentation begin ###

=head1 NAME

Paws::RDS::DescribeAccountAttributes - Arguments for method DescribeAccountAttributes on L<Paws::RDS>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeAccountAttributes on the
L<Amazon Relational Database Service|Paws::RDS> service. Use the attributes of this class
as arguments to method DescribeAccountAttributes.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeAccountAttributes.

=head1 SYNOPSIS

    my $rds = Paws->service('RDS');
    # To list account attributes
    # This example lists account attributes.
    my $AccountAttributesMessage = $rds->DescribeAccountAttributes();


Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/rds/DescribeAccountAttributes>

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeAccountAttributes in L<Paws::RDS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
